@@ -92,6 +92,7 @@ struct OneDist : public RcppParallel::Worker
             // These have to be reserved within the parallel operator function!
             std::fill (w.begin (), w.end (), INFINITE_DOUBLE);
             std::fill (d.begin (), d.end (), INFINITE_DOUBLE);
+            d [from_i] = w [from_i] = 0.0;
 
             if (is_spatial)
             {
@@ -165,6 +166,7 @@ struct OneIso : public RcppParallel::Worker
             std::fill (w.begin (), w.end (), INFINITE_DOUBLE);
             std::fill (d.begin (), d.end (), INFINITE_DOUBLE);
             std::fill (prev.begin (), prev.end (), INFINITE_INT);
+            d [from_i] = w [from_i] = 0.0;
 
             pathfinder->DijkstraLimit (d, w, prev, from_i, dlimit_max);
 
@@ -176,13 +178,10 @@ struct OneIso : public RcppParallel::Worker
                 if (j < INFINITE_INT)
                 {
                     size_t sj = static_cast <size_t> (j);
-                    if (prev [sj] == INFINITE_INT && w [sj] < dlimit_max)
+                    if (sj < INFINITE_INT && prev [sj] == INFINITE_INT &&
+                            w [sj] < dlimit_max)
                     {
-                        // # nocov start
-                        if (terminal_verts.find (j) != terminal_verts.end ())
-                            terminal_verts.erase (j);
-                        terminal_verts.emplace (prev [sj]);
-                        // # nocov end
+                        terminal_verts.emplace (prev [sj]); // # nocov
                     }
                 }
             }
@@ -199,9 +198,9 @@ struct OneIso : public RcppParallel::Worker
                 {
                     for (auto k: dlimit)
                     {
-                        size_t sp = static_cast <size_t> (prev [j]);
-                        if (w [j] > k && w[sp] < k)
-                            dout (i, sp) = -k; // flag isohull verts with -k
+                        size_t st_prev = static_cast <size_t> (prev [j]);
+                        if (w [j] > k && w [st_prev] < k)
+                            dout (i, st_prev) = -k; // flag isohull verts with -k
                         else
                             dout (i, j) = w [j]; // distance of other internal verts
                     }
@@ -405,6 +404,7 @@ Rcpp::NumericMatrix rcpp_get_sp_dists (const Rcpp::DataFrame graph,
         Rcpp::checkUserInterrupt ();
         std::fill (w.begin(), w.end(), INFINITE_DOUBLE);
         std::fill (d.begin(), d.end(), INFINITE_DOUBLE);
+        d [fromi [i]] = w [fromi [i]] = 0.0;
 
         pathfinder->Dijkstra (d, w, prev,
                 static_cast <unsigned int> (fromi [i]), toi);
@@ -483,7 +483,8 @@ Rcpp::List rcpp_get_paths (const Rcpp::DataFrame graph,
         Rcpp::checkUserInterrupt ();
         std::fill (w.begin(), w.end(), INFINITE_DOUBLE);
         std::fill (d.begin(), d.end(), INFINITE_DOUBLE);
-        std::fill (prev.begin(), prev.end(), 0);
+        std::fill (prev.begin(), prev.end(), INFINITE_INT);
+        d [fromi [i]] = w [fromi [i]] = 0.0;
 
         pathfinder->Dijkstra (d, w, prev,
                 static_cast <unsigned int> (fromi [i]), toi);
